==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/PointSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { markType } from "igniteui-angular-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
export let PointSeries = /*@__PURE__*/ (() => {
    class PointSeries extends HorizontalAnchoredCategorySeries {
        constructor() {
            super();
            this.ab = PointSeries.$;
        }
        get_c5() {
            return true;
        }
        by() {
            return new PointSeriesView(this);
        }
        l4(a) {
            super.l4(a);
            this.vj = a;
        }
        g0() {
            return 0.7;
        }
        qf() {
            if (this.qe == 0) {
                return 2;
            }
            return super.qf();
        }
        ez(a, b) {
            let c = this.ps(this.px(a), true, false);
            if (this.qo(a, b)) {
                return true;
            }
            return false;
        }
        l9(a, b, c, d) {
            super.l9(a, b, c, d);
        }
        get useHighMarkerFidelity() {
            return this.ss;
        }
    }
    PointSeries.$t = markType(PointSeries, 'PointSeries', HorizontalAnchoredCategorySeries.$);
    return PointSeries;
})();
/**
 * @hidden
 */
export let PointSeriesView = /*@__PURE__*/ (() => {
    class PointSeriesView extends AnchoredCategorySeriesView {
        constructor(a) {
            super(a);
            this.da = null;
            this.da = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.b1.ql = Defaults.e;
            }
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.ph = a;
            this.e.g1 = 3;
            this.e.g2 = 2;
            this.e.g3 = 2;
            this.e.fb = false;
        }
    }
    PointSeriesView.$t = markType(PointSeriesView, 'PointSeriesView', AnchoredCategorySeriesView.$);
    return PointSeriesView;
})();

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm2015/lib/PointSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { markType } from "igniteui-angular-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
export let PointSeries = /*@__PURE__*/ (() => {
    class PointSeries extends HorizontalAnchoredCategorySeries {
        constructor() {
            super();
            this.ab = PointSeries.$;
        }
        get_dx() {
            return true;
        }
        cg() {
            return new PointSeriesView(this);
        }
        o0(a) {
            super.o0(a);
            this.ze = a;
        }
        iq() {
            return 0.7;
        }
        t4() {
            if (this.t3 == 0) {
                return 2;
            }
            return super.t4();
        }
        f4(a, b) {
            let c = this.th(this.tm(a), true, false);
            if (this.ud(a, b)) {
                return true;
            }
            return false;
        }
        o8(a, b, c, d) {
            super.o8(a, b, c, d);
        }
        get useHighMarkerFidelity() {
            return this.wi;
        }
    }
    PointSeries.$t = markType(PointSeries, 'PointSeries', HorizontalAnchoredCategorySeries.$);
    return PointSeries;
})();
/**
 * @hidden
 */
export let PointSeriesView = /*@__PURE__*/ (() => {
    class PointSeriesView extends AnchoredCategorySeriesView {
        constructor(a) {
            super(a);
            this.dd = null;
            this.dd = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.b4.ua = Defaults.e;
            }
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.s6 = a;
            this.e.ir = 3;
            this.e.is = 2;
            this.e.it = 2;
            this.e.gj = false;
        }
    }
    PointSeriesView.$t = markType(PointSeriesView, 'PointSeriesView', AnchoredCategorySeriesView.$);
    return PointSeriesView;
})();
